def init():
    global model_path
    model_path = None

    global resolution
    resolution = None

    global pet_path
    pet_path = None

    global ct_path
    ct_path = None
